"""Main test file that imports all tool-specific tests"""
from .test_tools_convert import *
from .test_tools_debug import *
from .test_tools_decorators import *
from .test_tools_dicts import *
from .test_tools_docs import *
from .test_tools_errors import *
from .test_tools_eval import *
from .test_tools_files import *
from .test_tools_formatting import *
from .test_tools_hyperlinks import *
from .test_tools_logging import *
from .test_tools_object import *
from .test_tools_platform import *
from .test_tools_print import *
from .test_tools_python import *
from .test_tools_settings import *
from .test_tools_sound_system import *
from .test_tools_sounds import *
from .test_tools_strings import *
from .test_tools_terminal import *
from .test_tools_time import *
from .test_tools_video import *
from .test_tools_voice import * 